from setuptools import setup

setup(
    name='bestemmie',
    packages=['bestemmie'],
    version='0.4',
    description='Bestemmie.org API for lazy person',
    keywords=['bestemmie', 'api', 'bestemmie.org'],
    url='https://github.com/Trafitto/bestemmie.org-API',
    author='Trafitto',
    install_requires=['requests'],
    author_email='develop@trafitto.com',
    license='MIT',
)
